@@ -22,33 +22,33 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 '
-           '-DNDEBUG    -fexceptions -g -grecord-gcc-switches -pipe -Wall '
+           '-DNDEBUG  -O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
            '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
            '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
            '-march=x86-64-v2 -mtune=generic -fasynchronous-unwind-tables '
            '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
-           '-fwrapv -fexceptions -g -grecord-gcc-switches -pipe -Wall '
+           '-fwrapv -O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
            '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
            '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
            '-march=x86-64-v2 -mtune=generic -fasynchronous-unwind-tables '
            '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
-           '-fwrapv    -fexceptions -g -grecord-gcc-switches -pipe -Wall '
+           '-fwrapv  -O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
            '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
            '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
            '-march=x86-64-v2 -mtune=generic -fasynchronous-unwind-tables '
            '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
-           '-fwrapv  -O3',
+           '-fwrapv',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+ 'CONFIGURE_CFLAGS': '-O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                      '-m64 -march=x86-64-v2 -mtune=generic '
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
                      '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv',
- 'CONFIGURE_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                             '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -92,7 +92,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-builtin-hashlib-hashes=blake2' '--with-valgrind' "
                 "'--without-ensurepip' '--enable-optimizations' "
                 "'build_alias=x86_64-redhat-linux-gnu' "
-                "'host_alias=x86_64-redhat-linux-gnu' 'CC=gcc' 'CFLAGS=   "
+                "'host_alias=x86_64-redhat-linux-gnu' 'CC=gcc' 'CFLAGS= -O2  "
                 '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                 '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                 '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
@@ -104,12 +104,12 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.9.19/build/optimized/coverage.info',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.9.19/build/optimized/lcov-report',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.9.20/build/optimized/coverage.info',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.9.20/build/optimized/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.9.19/Include',
+             '-I/builddir/build/BUILD/Python-3.9.20/Include',
  'CXX': 'g++',
  'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.9 '
              '/usr/lib64/python3.9/lib-dynload',
@@ -629,7 +629,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.9.19/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.9.20/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
@@ -659,7 +659,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    -fexceptions -g '
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  -fexceptions -g '
         '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
         '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
         '-fstack-protector-strong   -m64 -march=x86-64-v2 -mtune=generic '
@@ -698,7 +698,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    '
+                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
                              '-fexceptions -g -grecord-gcc-switches -pipe '
                              '-Wall -Werror=format-security '
                              '-Wp,-D_FORTIFY_SOURCE=2 '
@@ -706,21 +706,21 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-protector-strong   -m64 -march=x86-64-v2 '
                              '-mtune=generic -fasynchronous-unwind-tables '
                              '-fstack-clash-protection -fcf-protection '
-                             '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
+                             '-D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions -g '
                              '-grecord-gcc-switches -pipe -Wall '
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS  '
                              '-fstack-protector-strong   -m64 -march=x86-64-v2 '
                              '-mtune=generic -fasynchronous-unwind-tables '
                              '-fstack-clash-protection -fcf-protection '
-                             '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
-                             '-grecord-gcc-switches -pipe -Wall '
+                             '-D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions '
+                             '-g -grecord-gcc-switches -pipe -Wall '
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS  '
                              '-fstack-protector-strong   -m64 -march=x86-64-v2 '
                              '-mtune=generic -fasynchronous-unwind-tables '
                              '-fstack-clash-protection -fcf-protection '
-                             '-D_GNU_SOURCE -fPIC -fwrapv  -O3 -flto=auto '
+                             '-D_GNU_SOURCE -fPIC -fwrapv -O2 -flto=auto '
                              '-ffat-lto-objects -fexceptions -g '
                              '-grecord-gcc-switches -pipe -Wall '
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
@@ -738,10 +738,10 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden -flto=auto -ffat-lto-objects '
-                             '-fexceptions -g -grecord-gcc-switches -pipe '
-                             '-Wall -Werror=format-security '
-                             '-Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fvisibility=hidden -O2 -flto=auto '
+                             '-ffat-lto-objects -fexceptions -g '
+                             '-grecord-gcc-switches -pipe -Wall '
+                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                              '-fstack-protector-strong '
@@ -750,30 +750,30 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection -fcf-protection '
                              '-D_GNU_SOURCE -fPIC -fwrapv '
-                             '-fno-semantic-interposition -O3 -fprofile-use '
+                             '-fno-semantic-interposition  -O3 -fprofile-use '
                              '-fprofile-correction '
-                             '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
+                             '-I/builddir/build/BUILD/Python-3.9.20/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/builddir/build/BUILD/Python-3.9.19/Include '
+                             '-I/builddir/build/BUILD/Python-3.9.20/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
-              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    -fexceptions -g '
+              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -march=x86-64-v2 -mtune=generic '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
-              '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+              '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions '
+              '-g -grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -march=x86-64-v2 -mtune=generic '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
-              '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+              '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions '
+              '-g -grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -march=x86-64-v2 -mtune=generic '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O3',
- 'PY_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
+              '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv',
+ 'PY_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -788,7 +788,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-Wextra -Wno-unused-result -Wno-unused-parameter '
                      '-Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden -flto=auto -ffat-lto-objects '
+                     '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
                      '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -798,32 +798,32 @@ build_time_vars = {'ABIFLAGS': '',
                      '-march=x86-64-v2 -mtune=generic '
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
                      '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv '
-                     '-fno-semantic-interposition -O3 -fprofile-use '
+                     '-fno-semantic-interposition  -O3 -fprofile-use '
                      '-fprofile-correction '
-                     '-I/builddir/build/BUILD/Python-3.9.19/Include/internal',
+                     '-I/builddir/build/BUILD/Python-3.9.20/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    -fexceptions '
-                   '-g -grecord-gcc-switches -pipe -Wall '
-                   '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-                   '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
-                   '-march=x86-64-v2 -mtune=generic '
-                   '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -fexceptions '
-                   '-g -grecord-gcc-switches -pipe -Wall '
-                   '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-                   '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
-                   '-march=x86-64-v2 -mtune=generic '
-                   '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv    '
+                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                    '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
                    '-march=x86-64-v2 -mtune=generic '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O3 '
-                   '-flto=auto -ffat-lto-objects -fexceptions -g '
-                   '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+                   '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -O2  '
+                   '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+                   '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                   '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
+                   '-march=x86-64-v2 -mtune=generic '
+                   '-fasynchronous-unwind-tables -fstack-clash-protection '
+                   '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O2  '
+                   '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+                   '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                   '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
+                   '-march=x86-64-v2 -mtune=generic '
+                   '-fasynchronous-unwind-tables -fstack-clash-protection '
+                   '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -O2 -flto=auto '
+                   '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
+                   '-pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-fstack-protector-strong '
@@ -836,7 +836,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-flto=auto -ffat-lto-objects -fexceptions -g '
+                   '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -845,11 +845,11 @@ build_time_vars = {'ABIFLAGS': '',
                    '-march=x86-64-v2 -mtune=generic '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
                    '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv '
-                   '-fno-semantic-interposition -O3 -fprofile-use '
+                   '-fno-semantic-interposition  -O3 -fprofile-use '
                    '-fprofile-correction '
-                   '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
+                   '-I/builddir/build/BUILD/Python-3.9.20/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.9.19/Include -fPIC '
+                   '-I/builddir/build/BUILD/Python-3.9.20/Include -fPIC '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  '
                     '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g '
@@ -863,7 +863,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                     '-fno-semantic-interposition -g',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.9.19/Include',
+                '-I/builddir/build/BUILD/Python-3.9.20/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  -Wl,-z,relro '
                '-Wl,--as-needed  -Wl,-z,now    -g',
@@ -880,25 +880,25 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -march=x86-64-v2 -mtune=generic '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv '
+                        '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -O2  '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -march=x86-64-v2 -mtune=generic '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv    '
+                        '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O2  '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -march=x86-64-v2 -mtune=generic '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O3 '
+                        '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -O2 '
                         '-flto=auto -ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
@@ -914,7 +914,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden -flto=auto -ffat-lto-objects '
+                        '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -924,11 +924,11 @@ build_time_vars = {'ABIFLAGS': '',
                         '-march=x86-64-v2 -mtune=generic '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
                         '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv '
-                        '-fno-semantic-interposition -O3 -fprofile-use '
+                        '-fno-semantic-interposition  -O3 -fprofile-use '
                         '-fprofile-correction '
-                        '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
+                        '-I/builddir/build/BUILD/Python-3.9.20/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/builddir/build/BUILD/Python-3.9.19/Include -fPIC',
+                        '-I/builddir/build/BUILD/Python-3.9.20/Include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -937,7 +937,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.19/build/optimized',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.20/build/optimized',
  'SCRIPTDIR': '/usr/lib64',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -966,7 +966,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-39-x86_64-linux-gnu',
  'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.9.19/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.9.20/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -978,12 +978,12 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.19/build/optimized '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.20/build/optimized '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.19/build/optimized '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.20/build/optimized '
                './python '
-               '/builddir/build/BUILD/Python-3.9.19/Tools/scripts/run_tests.py',
+               '/builddir/build/BUILD/Python-3.9.20/Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -992,10 +992,10 @@ build_time_vars = {'ABIFLAGS': '',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3.9 '
-                '/builddir/build/BUILD/Python-3.9.19/Tools/scripts/update_file.py',
+                '/builddir/build/BUILD/Python-3.9.20/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.9',
- 'VPATH': '/builddir/build/BUILD/Python-3.9.19',
+ 'VPATH': '/builddir/build/BUILD/Python-3.9.20',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -1007,9 +1007,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.9.19/build/optimized',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.9.19',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.9.20/build/optimized',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.9.20',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.9.19'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.9.20'}
